@@ -1,23 +1,24 @@
-/* Glide theme engine
- * Copyright (C) 2006 Andrew Johnson
+/* Glide - a cairo based GTK+ engine
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * Written by Andrew Johnson <acjgenius@earthlink.net>
- */ 
+ */
+
 
 #include "glide_gtk2_engine.h"
 #include "glide_gtk2_support.h"
@@ -43,31 +44,6 @@ ge_blend_color(const CairoColor *color1, const CairoColor *color2, CairoColor *c
 	composite->a = (color1->a + color2->a)/2;	
 }
 
-void
-ge_cairo_pattern_add_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoColor *color)
-{
-	g_return_if_fail (pattern && color);
-	
-	cairo_pattern_add_color_stop_rgba(pattern, offset, color->r, color->g, color->b, color->a);	
-}
-
-void
-ge_cairo_pattern_add_shade_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoColor *color, gdouble shade)
-{
-	CairoColor shaded;
-
-	g_return_if_fail (pattern && color && (shade >= 0) && (shade <= 3));
-
-	shaded = *color;
-
-	if (shade != 1)
-	{
-		ge_shade_color(color, shade, &shaded);
-	}
-
-	cairo_pattern_add_color_stop_rgba(pattern, offset, shaded.r, shaded.g, shaded.b, shaded.a);	
-}
-
 typedef struct 
 {
 	cairo_path_t *clip;
@@ -76,74 +52,6 @@ typedef struct
 	cairo_pattern_t **layers;
 } GlideFill;
 
-void glide_draw_pattern_fill(cairo_t *canvas,
-					CairoPattern *pattern,
-					gint x,
-					gint y,
-					gint width,
-					gint height)
-{
-	cairo_matrix_t original_matrix, current_matrix;
-
-	if (pattern->operator == CAIRO_OPERATOR_DEST)
-	{
-		return;
-	}
-
-	cairo_pattern_get_matrix(pattern->handle, &original_matrix);
-	current_matrix = original_matrix;
-
-	if (pattern->scale != GLIDE_DIRECTION_NONE)
-	{
-		gdouble scale_x = 1.0;
-		gdouble scale_y = 1.0;
-
-		if ((pattern->scale == GLIDE_DIRECTION_VERTICAL) || (pattern->scale == GLIDE_DIRECTION_BOTH))
-		{
-			scale_x = 1.0/width;
-		}
-
-		if ((pattern->scale == GLIDE_DIRECTION_HORIZONTAL) || (pattern->scale == GLIDE_DIRECTION_BOTH))
-		{
-			scale_y = 1.0/height;
-		}
-
-		cairo_matrix_scale(&current_matrix, scale_x, scale_y);
-	}
-
-	if (pattern->translate != GLIDE_DIRECTION_NONE)
-	{
-		gdouble translate_x = 0;
-		gdouble translate_y = 0;
-
-		if ((pattern->translate == GLIDE_DIRECTION_VERTICAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
-		{
-			translate_x = 0.0-x;
-		}
-
-		if ((pattern->translate == GLIDE_DIRECTION_HORIZONTAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
-		{
-			translate_y = 0.0-y;
-		}
-
-		cairo_matrix_translate(&current_matrix, translate_x, translate_y);
-	}
-
-	cairo_pattern_set_matrix(pattern->handle, &current_matrix);
-
-	cairo_save(canvas);
-
-	cairo_set_source(canvas, pattern->handle);
-        cairo_set_operator(canvas, pattern->operator);
-	cairo_rectangle(canvas, x, y, width, height);
-
-	cairo_fill (canvas);
-
-	cairo_restore(canvas);
-
-	cairo_pattern_set_matrix(pattern->handle, &original_matrix);
-}
-
 static void 
 glide_simple_border_gap_clip(cairo_t *canvas,
 				gint x,
@@ -385,7 +293,7 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 							color1 = midtone;
 							color2 = darktone;
 							color3 = lighttone;
-							color4 = (border_type==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
+							color4 = (bevel_style==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
 
 							outer_overlap = FALSE;
 							inner_overlap = TRUE;
@@ -395,7 +303,7 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 							color1 = midtone;
 							color2 = lighttone;
 							color3 = darktone;
-							color4 = (border_type==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
+							color4 = (bevel_style==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
 
 							outer_overlap = TRUE;
 							inner_overlap = (gap_side == GLIDE_SIDE_NONE) || 
@@ -481,7 +389,7 @@ do_glide_draw_option_check(cairo_t *canvas,
 	{
 		case GLIDE_CHECK_ON:
 		{
-			cairo_arc(canvas, center_x, center_y, radius*0.68, 0, 2 * M_PI);
+			cairo_arc(canvas, center_x, center_y, radius*0.68, 0, 2 * G_PI);
 			cairo_fill(canvas);
 		}
 		break;
@@ -539,7 +447,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 		|| (bevel_style == GLIDE_BEVEL_STYLE_NONE)) 
 	{
 		ge_cairo_set_color(canvas, fill_color);
-		cairo_arc(canvas, center_x, center_y, radius, 0, 2 * M_PI);
+		cairo_arc(canvas, center_x, center_y, radius, 0, 2 * G_PI);
 		cairo_fill(canvas);
 
 		do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 1);
@@ -557,7 +465,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 						center_x, center_y, radius);
 
 		ge_cairo_set_color(canvas, fill_color);
-		cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * M_PI);
+		cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * G_PI);
 		cairo_fill(canvas);
 
 		do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 2);
@@ -597,7 +505,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius - 1);		
 
 			ge_cairo_set_color(canvas, fill_color);
-			cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * M_PI);
+			cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * G_PI);
 			cairo_fill(canvas);
 
 			do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 3);
@@ -627,7 +535,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius);
 
 				ge_cairo_set_color(canvas, fill_color);
-				cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * M_PI);
+				cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * G_PI);
 				cairo_fill(canvas);
 
 				do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 2);
@@ -669,14 +577,14 @@ do_glide_draw_round_option(cairo_t *canvas,
 							outer_color1 = midtone;
 							inner_color1 = darktone;
 							outer_color2 = lighttone;
-							inner_color2 = (border_type==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
+							inner_color2 = (bevel_style==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
 						}
 						else
 						{						
 							outer_color1 = midtone;
 							inner_color1 = lighttone;
 							outer_color2 = darktone;
-							inner_color2 = (border_type==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
+							inner_color2 = (bevel_style==GLIDE_BEVEL_STYLE_SMOOTHER)?*base:midtone;
 						}
 						
 						invert_in = FALSE;
@@ -702,7 +610,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius - 1);
 
 				ge_cairo_set_color(canvas, fill_color);
-				cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * M_PI);
+				cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * G_PI);
 				cairo_fill(canvas);
 
 				do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 3);
@@ -833,8 +741,8 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_new_path (canvas);
 
       cairo_move_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
 
       cairo_close_path (canvas);
@@ -844,7 +752,7 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, br);
-      cairo_arc(canvas, center_x, center_y, radius, 0,  2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0,  2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
@@ -853,8 +761,8 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_new_path (canvas);
 
       cairo_move_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
 
       cairo_close_path (canvas);
@@ -862,7 +770,7 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, tl); 
-      cairo_arc(canvas, center_x, center_y, radius, 0, 2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0, 2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
@@ -1068,21 +976,21 @@ do_glide_draw_dot (cairo_t *canvas,
 			gint y)
 {
 	ge_cairo_set_color(canvas, dark);	
-	cairo_rectangle (canvas, x - 1, y, 0.5, 0.5);
-	cairo_rectangle (canvas, x - 1, y - 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x, y - 1, 0.5, 0.5);
-	cairo_stroke(canvas);
+	cairo_rectangle (canvas, x - 1, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 0, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 1, y - 0, 1, 1);
+	cairo_fill(canvas);
 
 	ge_cairo_set_color(canvas, light);	
-	cairo_rectangle (canvas, x + 1, y, 0.5, 0.5);
-	cairo_rectangle (canvas, x + 1, y + 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x, y + 1, 0.5, 0.5);
-	cairo_stroke(canvas);
+	cairo_rectangle (canvas, x + 1, y + 1, 1, 1);
+	cairo_rectangle (canvas, x + 0, y + 1, 1, 1);
+	cairo_rectangle (canvas, x + 1, y + 0, 1, 1);
+	cairo_fill(canvas);
 
 	ge_cairo_set_color(canvas, mid);	
-	cairo_rectangle (canvas, x + 1, y - 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x - 1, y + 1, 0.5, 0.5);
-	cairo_stroke(canvas);
+	cairo_rectangle (canvas, x + 1, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 1, y + 1, 1, 1);
+	cairo_fill(canvas);
 }
 
 void
@@ -1216,7 +1124,7 @@ glide_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_WIDGET(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
 	              (pointer_y >= GTK_WIDGET(child->data)->allocation.y) &&
@@ -1264,13 +1172,13 @@ glide_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
                   if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
-                         GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
+                         gtk_widget_get_visible (GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
-                         GTK_WIDGET_VISIBLE(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
+                         gtk_widget_get_visible (GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
 	          {
                     gtk_widget_set_state (GTK_WIDGET(child->data), GTK_STATE_NORMAL);
                   }
@@ -1301,25 +1209,25 @@ glide_gtk2_engine_hack_menu_shell_setup(GtkWidget *widget)
       if (!g_object_get_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_HACK_SET"))
       {
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_motion,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_motion,
                                              NULL);
                                   
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_MOTION_ID", (gpointer)id);
         
         id = g_signal_connect(G_OBJECT(widget), "leave-notify-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_leave,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_leave,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_LEAVE_ID", (gpointer)id);
                                              
         id = g_signal_connect(G_OBJECT(widget), "destroy-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_destroy,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_destroy,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_DESTROY_ID", (gpointer)id);
  
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_HACK_SET", (gpointer)1);
         
         id = g_signal_connect(G_OBJECT(widget), "style-set",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_style_set,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_style_set,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_STYLE_SET_ID", (gpointer)id);
       }
