@@ -1,27 +1,31 @@
-/*
- * HighContrast GTK+ rendering engine for Gnome-Themes.
- *
- * Copyright 2003 Sun Microsystems Inc.
- *
- * Also contains code from GTK+, 
- * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+/* High Contrast - a cairo based GTK+ engine
+ * Copyright (C) 2003 Sun Microsystems Inc.
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
+ *
+ *
+ * This file contains code from GTK+, 
+ * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball, and Josh MacDonald,
+ * which is also available under the GNU LGPL 2.1 and later versions
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
  */
 
+
 #include "hc_gtk2_engine.h"
 #include "hc_gtk2_support.h"
 #include "hc_gtk2_drawing.h"
@@ -130,7 +134,7 @@ hc_draw_shadow(GtkStyle * style,
 		if ((widget) && (widget->parent))
 		{
 			gtk_widget_ensure_style(widget->parent);
-			ge_gdk_color_to_cairo(&widget->parent->style->fg[GTK_WIDGET_STATE(widget)], &foreground);
+			ge_gdk_color_to_cairo(&widget->parent->style->fg[gtk_widget_get_state (widget)], &foreground);
 		}
 	}
 
@@ -195,10 +199,10 @@ hc_draw_shadow_gap (GtkStyle       *style,
 	/***********************************************/
 	line_width = HC_STYLE(style)->edge_thickness;
 
-	if (gap_size > 0)
+	if (CHECK_DETAIL (detail, "notebook"))
 	{
-		gap_pos += floor(line_width/2.0) + 1; 
-		gap_size -= (floor(line_width/2.0) + 1)*2;
+		gap_pos += line_width;
+		gap_size -= 2*line_width;
 	}
 
 	/***********************************************/
@@ -379,11 +383,17 @@ hc_draw_flat_box (GtkStyle	*style,
                   gint		 height)
 {
 	if (detail && !strcmp ("tooltip", detail))
+	{
 		hc_draw_box (style, window, state_type, shadow_type, area,
 				widget, detail, x, y, width, height);
+	}
 	else
+	{
+		GtkStyleClass *hc_parent_class;
+		hc_parent_class = GTK_STYLE_CLASS (g_type_class_peek_parent (G_OBJECT_GET_CLASS(style)));
 		hc_parent_class->draw_flat_box (style, window, state_type, shadow_type, area,
 							widget, detail, x, y, width, height);
+	}
 }
 
 
@@ -424,7 +434,7 @@ hc_draw_box (GtkStyle	*style,
 	/* Draw Fill                                   */
 	/***********************************************/
 	gtk_style_apply_default_background (style, window,
-        					widget && !GTK_WIDGET_NO_WINDOW (widget),
+        					widget && !gtk_widget_get_has_window (widget),
 						state_type, area, x, y, width, height);
   
 
@@ -468,7 +478,7 @@ hc_draw_box_gap (GtkStyle       *style,
 	/* Draw Fill                                   */
 	/***********************************************/
 	gtk_style_apply_default_background (style, window,
-	                                    widget && !GTK_WIDGET_NO_WINDOW (widget),
+	                                    widget && !gtk_widget_get_has_window (widget),
 	                                    state_type, area, x, y, width, height);
 
 
